@@ -1155,6 +1155,8 @@ class Queue:
         Returns:
             Job: The enqueued job
         """
+        self.log.debug('Enqueueing job %s to queue %s (at_front=%s)', job.id, self.name, at_front)
+
         pipe = pipeline if pipeline is not None else self.connection.pipeline()
 
         job.redis_server_version = self.get_redis_server_version()
@@ -1265,6 +1267,13 @@ class Queue:
                 if not jobs_to_enqueue:
                     break
 
+                self.log.debug(
+                    'Enqueueing %d dependent jobs for job %s: %s',
+                    len(jobs_to_enqueue),
+                    job.id,
+                    [j.id for j in jobs_to_enqueue],
+                )
+
                 for dependent in jobs_to_enqueue:
                     enqueue_at_front = dependent.enqueue_at_front or False
 
@@ -1272,10 +1281,23 @@ class Queue:
                         dependent.origin, self.connection, job_class=self.job_class, serializer=self.serializer
                     )
                     registry.remove(dependent, pipeline=pipe)
+                    self.log.debug('Removed job %s from DeferredJobRegistry', dependent.id)
 
                     if dependent.origin == self.name:
+                        self.log.debug(
+                            'Enqueueing job %s to current queue %s (at_front=%s)',
+                            dependent.id,
+                            self.name,
+                            enqueue_at_front,
+                        )
                         self._enqueue_job(dependent, pipeline=pipe, at_front=enqueue_at_front)
                     else:
+                        self.log.debug(
+                            'Enqueueing job %s to different queue %s (at_front=%s)',
+                            dependent.id,
+                            dependent.origin,
+                            enqueue_at_front,
+                        )
                         queue = self.__class__(name=dependent.origin, connection=self.connection)
                         queue._enqueue_job(dependent, pipeline=pipe, at_front=enqueue_at_front)
 
