@@ -280,7 +280,7 @@ class TestWorker(RQTestCase):
         w.perform_job(job, queue)
 
         # An exception should be logged here at ERROR level
-        self.assertIn('Traceback', mock_logger_error.call_args[0][3])
+        self.assertIn('DeserializationError', mock_logger_error.call_args[0][3])
 
     def test_heartbeat(self):
         """Heartbeat saves last_heartbeat"""
@@ -827,12 +827,22 @@ class TestWorker(RQTestCase):
         worker = Worker([q], job_class=CustomJob)
         self.assertEqual(worker.job_class, CustomJob)
 
+        # Test job_class as string
+        worker_string = Worker([q], job_class='tests.fixtures.CustomJob')
+        from tests.fixtures import CustomJob as FixturesCustomJob
+        self.assertEqual(worker_string.job_class, FixturesCustomJob)
+
     def test_custom_queue_class(self):
         """Ensure Worker accepts custom queue class."""
         q = CustomQueue(connection=self.connection)
         worker = Worker([q], queue_class=CustomQueue)
         self.assertEqual(worker.queue_class, CustomQueue)
 
+        # Test queue_class as string
+        q_generic = Queue(connection=self.connection)
+        worker_string = Worker([q_generic], queue_class='rq.Queue')
+        self.assertEqual(worker_string.queue_class, Queue)
+
     def test_custom_queue_class_is_not_global(self):
         """Ensure Worker custom queue class is not global."""
         q = CustomQueue(connection=self.connection)
@@ -853,6 +863,11 @@ class TestWorker(RQTestCase):
         self.assertEqual(worker_generic.job_class, Job)
         self.assertEqual(Worker.job_class, Job)
 
+        # Test both job_class and queue_class as strings
+        worker = Worker([q], job_class='tests.fixtures.CustomJob')
+        from tests.fixtures import CustomJob as FixturesCustomJob
+        self.assertEqual(worker.job_class, FixturesCustomJob)
+
     def test_work_via_simpleworker(self):
         """Worker processes work, with forking disabled,
         then returns."""
@@ -1602,7 +1617,7 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
         self.assertFalse(os.path.exists(os.path.join(self.sandbox, 'finished')))
 
     @mock.patch('rq.worker.logger.info')
-    def test_handle_shutdown_request(self, mock_logger_info):
+    def test_handle_shutdown_request(self, mock_logger):
         """Mutate HerokuWorker so _horse_pid refers to an artificial process
         and test handle_warm_shutdown_request"""
         w = HerokuWorker('foo', connection=self.connection)
@@ -1619,7 +1634,7 @@ class HerokuWorkerShutdownTestCase(TimeoutTestCase, RQTestCase):
         # would expect p.exitcode to be -34
         self.assertEqual(p.exitcode, -34)
         self.assertFalse(os.path.exists(path))
-        mock_logger_info.assert_called_with('Killed horse pid %s', p.pid)
+        mock_logger.assert_called_with('Worker %s: killed horse pid %s', w.name, p.pid)
 
     def test_handle_shutdown_request_no_horse(self):
         """Mutate HerokuWorker so _horse_pid refers to non existent process
